@@ -1,21 +1,9 @@
 /*
  *  displaycalendar.cpp  -  KAlarm display calendar file access
  *  Program:  kalarm
- *  Copyright © 2001-2020 David Jarvie <djarvie@kde.org>
+ *  SPDX-FileCopyrightText: 2001-2020 David Jarvie <djarvie@kde.org>
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License along
- *  with this program; if not, write to the Free Software Foundation, Inc.,
- *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ *  SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "displaycalendar.h"
@@ -36,6 +24,8 @@
 using namespace KCalendarCore;
 using namespace KAlarmCal;
 
+//clazy:excludeall=non-pod-global-static
+
 
 namespace
 {
@@ -209,7 +199,7 @@ void DisplayCalendar::close()
     mOpen = false;
 
     // Events list should be empty, but just in case...
-    for (KAEvent* event : mEventList)
+    for (KAEvent* event : qAsConst(mEventList))
     {
         mEventMap.remove(event->id());
         delete event;
@@ -225,7 +215,7 @@ void DisplayCalendar::close()
 void DisplayCalendar::updateKAEvents()
 {
     qCDebug(KALARM_LOG) << "DisplayCalendar::updateKAEvents";
-    for (KAEvent* event : mEventList)
+    for (KAEvent* event : qAsConst(mEventList))
     {
         mEventMap.remove(event->id());
         delete event;
@@ -236,12 +226,12 @@ void DisplayCalendar::updateKAEvents()
         return;
 
     const Event::List kcalevents = cal->rawEvents();
-    for (Event::Ptr kcalevent : kcalevents)
+    for (const Event::Ptr& kcalevent : kcalevents)
     {
         if (kcalevent->alarms().isEmpty())
             continue;    // ignore events without alarms
 
-        KAEvent* event = new KAEvent(kcalevent);
+        auto* event = new KAEvent(kcalevent);
         if (!event->isValid())
         {
             qCWarning(KALARM_LOG) << "DisplayCalendar::updateKAEvents: Ignoring unusable event" << kcalevent->uid();
@@ -269,7 +259,7 @@ bool DisplayCalendar::addEvent(KAEvent& evnt)
         return false;
 
     Event::Ptr kcalEvent(new Event);
-    KAEvent* event = new KAEvent(evnt);
+    auto* event = new KAEvent(evnt);
     QString id = event->id();
     if (id.isEmpty())
         id = kcalEvent->uid();
