@@ -1,21 +1,9 @@
 /*
  *  latecancel.cpp  -  widget to specify cancellation if late
  *  Program:  kalarm
- *  Copyright © 2004-2020 David Jarvie <djarvie@kde.org>
+ *  SPDX-FileCopyrightText: 2004-2020 David Jarvie <djarvie@kde.org>
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License along
- *  with this program; if not, write to the Free Software Foundation, Inc.,
- *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ *  SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "latecancel.h"
@@ -49,14 +37,14 @@ LateCancelSelector::LateCancelSelector(bool allowHourMinute, QWidget* parent)
                              "<para>If unchecked, the alarm will be triggered at the first opportunity after "
                              "its scheduled time, regardless of how late it is.</para>");
 
-    QVBoxLayout* topLayout = new QVBoxLayout(this);
+    auto* topLayout = new QVBoxLayout(this);
     topLayout->setContentsMargins(0, 0, 0, 0);
 
     mStack = new QStackedWidget(this);
     topLayout->addWidget(mStack, 0, Qt::AlignLeft);
     mCheckboxFrame = new QFrame();
     mStack->addWidget(mCheckboxFrame);
-    QHBoxLayout* hlayout = new QHBoxLayout(mCheckboxFrame);
+    auto* hlayout = new QHBoxLayout(mCheckboxFrame);
     hlayout->setContentsMargins(0, 0, 0, 0);
     mCheckbox = new CheckBox(i18n_chk_CancelIfLate(), mCheckboxFrame);
     connect(mCheckbox, &CheckBox::toggled, this, &LateCancelSelector::slotToggled);
