@@ -1,21 +1,9 @@
 /*
  *  lineedit.cpp  -  Line edit widget with extra drag and drop options
  *  Program:  kalarm
- *  Copyright © 2003-2020 David Jarvie <djarvie@kde.org>
+ *  SPDX-FileCopyrightText: 2003-2020 David Jarvie <djarvie@kde.org>
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License along
- *  with this program; if not, write to the Free Software Foundation, Inc.,
- *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ *  SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "lineedit.h"
@@ -62,7 +50,7 @@ void LineEdit::init()
     if (mType == Url)
     {
         setCompletionMode(KCompletion::CompletionShell);
-        KUrlCompletion* comp = new KUrlCompletion(KUrlCompletion::FileCompletion);
+        auto* comp = new KUrlCompletion(KUrlCompletion::FileCompletion);
         comp->setReplaceHome(true);
         setCompletionObject(comp);
         setAutoDeleteCompletionObject(true);
@@ -184,7 +172,7 @@ void LineEdit::dropEvent(QDropEvent* e)
         }
     }
 
-    if (newEmails.count())
+    if (!newEmails.isEmpty())
     {
         newText = newEmails.join(QLatin1Char(','));
         const int c = cursorPosition();
