@@ -1,21 +1,9 @@
 /*
  *  spinbox2.cpp  -  spin box with extra pair of spin buttons
  *  Program:  kalarm
- *  Copyright © 2001-2020 David Jarvie <djarvie@kde.org>
+ *  SPDX-FileCopyrightText: 2001-2020 David Jarvie <djarvie@kde.org>
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License along
- *  with this program; if not, write to the Free Software Foundation, Inc.,
- *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ *  SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "spinbox2.h"
@@ -28,7 +16,6 @@
 #include <QGraphicsPixmapItem>
 #include <QPainter>
 #include <QTimer>
-#include <QFrame>
 #include <QBrush>
 #include <QApplication>
 #include <QPixmap>
@@ -92,9 +79,8 @@ void SpinBox2::init()
     mSpinMirror = new SpinMirror(mUpdown2, mSpinbox, this);
     mSpinbox->installEventFilter(this);
     mUpdown2->installEventFilter(this);
-    connect(mSpinbox, SIGNAL(valueChanged(int)), SLOT(valueChange()));
-    connect(mSpinbox, SIGNAL(valueChanged(int)), SIGNAL(valueChanged(int)));
-    connect(mSpinbox, SIGNAL(valueChanged(QString)), SIGNAL(valueChanged(QString)));
+    connect(mSpinbox, &QSpinBox::valueChanged, this, &SpinBox2::valueChange);
+    connect(mSpinbox, &QSpinBox::valueChanged, this, &SpinBox2::valueChanged);
     connect(mUpdown2, &SpinBox::stepped, this, &SpinBox2::stepPage);
     connect(mUpdown2, &ExtraSpinBox::painted, this, &SpinBox2::paintTimer);
 }
@@ -320,14 +306,14 @@ bool SpinBox2::eventFilter(QObject* obj, QEvent* e)
                 break;
             case QEvent::HoverEnter:
             {
-                QHoverEvent* he = (QHoverEvent*)e;
+                auto* he = (QHoverEvent*)e;
                 QApplication::postEvent(mUpdown2, new QHoverEvent(e->type(), QPoint(1, he->pos().y()), he->oldPos()));
                 updateButtons = true;
                 break;
             }
             case QEvent::HoverLeave:
             {
-                QHoverEvent* he = (QHoverEvent*)e;
+                auto* he = (QHoverEvent*)e;
                 QApplication::postEvent(mUpdown2, new QHoverEvent(e->type(), he->pos(), QPoint(1, he->oldPos().y())));
                 updateButtons = true;
                 break;
@@ -335,7 +321,7 @@ bool SpinBox2::eventFilter(QObject* obj, QEvent* e)
             case QEvent::FocusIn:
             case QEvent::FocusOut:
             {
-                QFocusEvent* fe = (QFocusEvent*)e;
+                auto* fe = (QFocusEvent*)e;
                 QApplication::postEvent(mUpdown2, new QFocusEvent(e->type(), fe->reason()));
                 updateButtons = true;
                 break;
