@@ -1,21 +1,9 @@
 /*
  *  timespinbox.cpp  -  time spinbox widget
  *  Program:  kalarm
- *  Copyright © 2001-2019 David Jarvie <djarvie@kde.org>
+ *  SPDX-FileCopyrightText: 2001-2020 David Jarvie <djarvie@kde.org>
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License along
- *  with this program; if not, write to the Free Software Foundation, Inc.,
- *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ *  SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "timespinbox.h"
@@ -48,7 +36,7 @@ TimeSpinBox::TimeSpinBox(bool use24hour, QWidget* parent)
     setShiftSteps(5, 360);    // shift-left button increments 5 min / 6 hours
     setSelectOnStep(false);
     setAlignment(Qt::AlignHCenter);
-    connect(this, static_cast<void (TimeSpinBox::*)(int)>(&TimeSpinBox::valueChanged), this, &TimeSpinBox::slotValueChanged);
+    connect(this, &TimeSpinBox::valueChanged, this, &TimeSpinBox::slotValueChanged);
 }
 
 /******************************************************************************
@@ -72,7 +60,7 @@ QString TimeSpinBox::shiftWhatsThis()
 
 QTime TimeSpinBox::time() const
 {
-    return QTime(value() / 60, value() % 60);
+    return {value() / 60, value() % 60};
 }
 
 QString TimeSpinBox::textFromValue(int v) const
@@ -240,14 +228,14 @@ QSize TimeSpinBox::sizeHint() const
 {
     QSize sz = SpinBox2::sizeHint();
     QFontMetrics fm(font());
-    return QSize(sz.width() + fm.horizontalAdvance(QLatin1Char(':')), sz.height());
+    return {sz.width() + fm.horizontalAdvance(QLatin1Char(':')), sz.height()};
 }
 
 QSize TimeSpinBox::minimumSizeHint() const
 {
     QSize sz = SpinBox2::minimumSizeHint();
     QFontMetrics fm(font());
-    return QSize(sz.width() + fm.horizontalAdvance(QLatin1Char(':')), sz.height());
+    return {sz.width() + fm.horizontalAdvance(QLatin1Char(':')), sz.height()};
 }
 
 /******************************************************************************
