@@ -1,21 +1,9 @@
 /*
  *  mainwindow.cpp  -  main application window
  *  Program:  kalarm
- *  Copyright © 2001-2020 David Jarvie <djarvie@kde.org>
+ *  SPDX-FileCopyrightText: 2001-2020 David Jarvie <djarvie@kde.org>
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License along
- *  with this program; if not, write to the Free Software Foundation, Inc.,
- *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ *  SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "mainwindow.h"
@@ -46,7 +34,6 @@
 #include "kalarm_debug.h"
 
 #include <KAlarmCal/AlarmText>
-#include <KAlarmCal/KAEvent>
 
 #include <AkonadiCore/Item>
 #include <KCalendarCore/MemoryCalendar>
@@ -66,6 +53,7 @@ using namespace KCalUtils;
 #include <KEditToolBar>
 #include <KXMLGUIFactory>
 #include <KToggleAction>
+#include <KNotifyConfigWidget>
 #include <KToolBarPopupAction>
 
 #include <QAction>
@@ -80,6 +68,7 @@ using namespace KCalUtils;
 #include <QMenu>
 #include <QMimeDatabase>
 #include <QInputDialog>
+#include <QTimer>
 #include <QUrl>
 #include <QMenuBar>
 #include <QSystemTrayIcon>
@@ -87,6 +76,8 @@ using namespace KCalUtils;
 
 using namespace KAlarmCal;
 
+//clazy:excludeall=non-pod-global-static
+
 namespace
 {
 const QString UI_FILE(QStringLiteral("kalarmui.rc"));
@@ -305,7 +296,7 @@ bool MainWindow::eventFilter(QObject* obj, QEvent* e)
         {
             case QEvent::KeyPress:
             {
-                QKeyEvent* ke = static_cast<QKeyEvent*>(e);
+                auto* ke = static_cast<QKeyEvent*>(e);
                 if (ke->key() == Qt::Key_Delete  &&  ke->modifiers() == Qt::ShiftModifier)
                 {
                     // Prevent Shift-Delete being processed by EventListDelegate
@@ -348,7 +339,7 @@ void MainWindow::resourcesResized()
 {
     if (!mShown  ||  mResizing)
         return;
-    QList<int> widths = mSplitter->sizes();
+    const QList<int> widths = mSplitter->sizes();
     if (widths.count() > 1)
     {
         mResourcesWidth = widths[0];
@@ -381,19 +372,20 @@ void MainWindow::showEvent(QShowEvent* se)
     }
     MainWindowBase::showEvent(se);
     mShown = true;
+
+    if (mMenuError)
+        QTimer::singleShot(0, this, &MainWindow::showMenuErrorMessage);
 }
 
 /******************************************************************************
-* Display the window.
+* Show the menu error message now that the main window has been displayed.
+* Waiting until now lets the user easily associate the message with the main
+* window which is faulty.
 */
-void MainWindow::show()
+void MainWindow::showMenuErrorMessage()
 {
-    MainWindowBase::show();
     if (mMenuError)
     {
-        // Show error message now that the main window has been displayed.
-        // Waiting until now lets the user easily associate the message with
-        // the main window which is faulty.
         KAMessageBox::error(this, xi18nc("@info", "Failure to create menus (perhaps <filename>%1</filename> missing or corrupted)", UI_FILE));
         mMenuError = false;
     }
@@ -542,19 +534,20 @@ void MainWindow::initActions()
     actions->setDefaultShortcuts(mActionRedo, redoShortcut);
     connect(mActionRedo, &KToolBarPopupAction::triggered, this, &MainWindow::slotRedo);
 
-    KStandardAction::find(mListView, SLOT(slotFind()), actions);
-    mActionFindNext = KStandardAction::findNext(mListView, SLOT(slotFindNext()), actions);
-    mActionFindPrev = KStandardAction::findPrev(mListView, SLOT(slotFindPrev()), actions);
-    KStandardAction::selectAll(mListView, SLOT(selectAll()), actions);
-    KStandardAction::deselect(mListView, SLOT(clearSelection()), actions);
+    KStandardAction::find(mListView, &EventListView::slotFind, actions);
+    mActionFindNext = KStandardAction::findNext(mListView, &EventListView::slotFindNext, actions);
+    mActionFindPrev = KStandardAction::findPrev(mListView, &EventListView::slotFindPrev, actions);
+    KStandardAction::selectAll(mListView, &QTreeView::selectAll, actions);
+    KStandardAction::deselect(mListView, &QAbstractItemView::clearSelection, actions);
     // Quit only once the event loop is called; otherwise, the parent window will
     // be deleted while still processing the action, resulting in a crash.
     QAction* act = KStandardAction::quit(nullptr, nullptr, actions);
     connect(act, &QAction::triggered, this, &MainWindow::slotQuit, Qt::QueuedConnection);
-    QAction* actionMenubar = KStandardAction::showMenubar(this, SLOT(slotShowMenubar()), actions);
-    KStandardAction::keyBindings(this, SLOT(slotConfigureKeys()), actions);
-    KStandardAction::configureToolbars(this, SLOT(slotConfigureToolbar()), actions);
-    KStandardAction::preferences(this, SLOT(slotPreferences()), actions);
+    QAction* actionMenubar = KStandardAction::showMenubar(this, &MainWindow::slotShowMenubar, actions);
+    KStandardAction::keyBindings(this, &MainWindow::slotConfigureKeys, actions);
+    KStandardAction::configureNotifications(this, &MainWindow::slotConfigureNotifications, actions);
+    KStandardAction::configureToolbars(this, &MainWindow::slotConfigureToolbar, actions);
+    KStandardAction::preferences(this, &MainWindow::slotPreferences, actions);
     mResourceSelector->initActions(actions);
     setStandardToolBarMenuEnabled(true);
     createGUI(UI_FILE);
@@ -572,8 +565,8 @@ void MainWindow::initActions()
     connect(mActionRedo->menu(), &QMenu::triggered, this, &MainWindow::slotRedoItem);
     connect(Undo::instance(), &Undo::changed, this, &MainWindow::slotUndoStatus);
     connect(mListView, &AlarmListView::findActive, this, &MainWindow::slotFindActive);
-    Preferences::connect(SIGNAL(archivedKeepDaysChanged(int)), this, SLOT(updateKeepArchived(int)));
-    Preferences::connect(SIGNAL(showInSystemTrayChanged(bool)), this, SLOT(updateTrayIconAction()));
+    Preferences::connect(&Preferences::archivedKeepDaysChanged, this, &MainWindow::updateKeepArchived);
+    Preferences::connect(&Preferences::showInSystemTrayChanged, this, &MainWindow::updateTrayIconAction);
     connect(theApp(), &KAlarmApp::trayIconToggled, this, &MainWindow::updateTrayIconAction);
 
     // Set menu item states
@@ -795,10 +788,11 @@ void MainWindow::slotReactivate()
 void MainWindow::slotEnable()
 {
     bool enable = mActionEnableEnable;    // save since changed in response to KAlarm::enableEvent()
-    QVector<KAEvent> events = mListView->selectedEvents();
+    const QVector<KAEvent> events = mListView->selectedEvents();
     QVector<KAEvent> eventCopies;
-    for (int i = 0, end = events.count();  i < end;  ++i)
-        eventCopies += events[i];
+    eventCopies.reserve(events.count());
+    for (const KAEvent& event : events)
+        eventCopies += event;
     KAlarm::enableEvents(eventCopies, enable, this);
     slotSelection();   // update Enable/Disable action text
 }
@@ -1018,7 +1012,7 @@ void MainWindow::slotRedo()
 */
 void MainWindow::slotUndoItem(QAction* action)
 {
-    int id = mUndoMenuIds[action];
+    int id = mUndoMenuIds.value(action);
     Undo::undo(id, this, Undo::actionText(Undo::UNDO, id));
 }
 
@@ -1027,7 +1021,7 @@ void MainWindow::slotUndoItem(QAction* action)
 */
 void MainWindow::slotRedoItem(QAction* action)
 {
-    int id = mUndoMenuIds[action];
+    int id = mUndoMenuIds.value(action);
     Undo::redo(id, this, Undo::actionText(Undo::REDO, id));
 }
 
@@ -1057,15 +1051,14 @@ void MainWindow::initUndoMenu(QMenu* menu, Undo::Type type)
     menu->clear();
     mUndoMenuIds.clear();
     const QString& action = (type == Undo::UNDO) ? undoTextStripped : redoTextStripped;
-    QList<int> ids = Undo::ids(type);
-    for (int i = 0, end = ids.count();  i < end;  ++i)
+    const QVector<int> ids = Undo::ids(type);
+    for (const int id : ids)
     {
-        int id = ids[i];
-        QString actText = Undo::actionText(type, id);
-        QString descrip = Undo::description(type, id);
-        QString text = descrip.isEmpty()
-                     ? i18nc("@action Undo/Redo [action]", "%1 %2", action, actText)
-                     : i18nc("@action Undo [action]: message", "%1 %2: %3", action, actText, descrip);
+        const QString actText = Undo::actionText(type, id);
+        const QString descrip = Undo::description(type, id);
+        const QString text = descrip.isEmpty()
+                           ? i18nc("@action Undo/Redo [action]", "%1 %2", action, actText)
+                           : i18nc("@action Undo [action]: message", "%1 %2: %3", action, actText, descrip);
         QAction* act = menu->addAction(text);
         mUndoMenuIds[act] = id;
     }
@@ -1132,6 +1125,14 @@ void MainWindow::slotConfigureKeys()
     KShortcutsDialog::configure(actionCollection(), KShortcutsEditor::LetterShortcutsAllowed, this);
 }
 
+/******************************************************************************
+* Called when the Configure Notifications menu item is selected.
+*/
+void MainWindow::slotConfigureNotifications()
+{
+    KNotifyConfigWidget::configure(this);
+}
+
 /******************************************************************************
 * Called when the Configure Toolbars menu item is selected.
 */
@@ -1218,7 +1219,6 @@ void MainWindow::executeDropEvent(MainWindow* win, QDropEvent* e)
     const QMimeData* data = e->mimeData();
     KAEvent::SubAction action = KAEvent::MESSAGE;
     AlarmText          alarmText;
-    QList<QUrl>        urls;
     MemoryCalendar::Ptr calendar(new MemoryCalendar(Preferences::timeSpecAsZone()));
 #ifndef NDEBUG
     const QString fmts = data->formats().join(QLatin1String(", "));
@@ -1276,7 +1276,7 @@ void MainWindow::executeDropEvent(MainWindow* win, QDropEvent* e)
             KAEvent::Flags flags = KAEvent::DEFAULT_FONT;
             if (start.isDateOnly())
                 flags |= KAEvent::ANY_TIME;
-            KAEvent ev(start, alarmText.displayText(), Preferences::defaultBgColour(), Preferences::defaultFgColour(),
+            KAEvent ev(start, todo->summary(), alarmText.displayText(), Preferences::defaultBgColour(), Preferences::defaultFgColour(),
                        QFont(), KAEvent::MESSAGE, 0, flags, true);
             ev.startChanges();
             if (todo->recurs())
@@ -1376,9 +1376,8 @@ void MainWindow::slotCalendarStatusChanged()
     // Find whether there are any writable calendars
     bool active  = !Resources::enabledResources(CalEvent::ACTIVE, true).isEmpty();
     bool templat = !Resources::enabledResources(CalEvent::TEMPLATE, true).isEmpty();
-    for (int i = 0, end = mWindowList.count();  i < end;  ++i)
+    for (MainWindow* w : qAsConst(mWindowList))
     {
-        MainWindow* w = mWindowList[i];
         w->mActionImportAlarms->setEnabled(active || templat);
         w->mActionImportBirthdays->setEnabled(active);
         w->mActionCreateTemplate->setEnabled(templat);
@@ -1525,7 +1524,7 @@ MainWindow* MainWindow::toggleWindow(MainWindow* win)
 * Called when the Edit button is clicked in an alarm message window.
 * This controls the alarm edit dialog created by the alarm window, and allows
 * it to remain unaffected by the alarm window closing.
-* See MessageWin::slotEdit() for more information.
+* See MessageWindow::slotEdit() for more information.
 */
 void MainWindow::editAlarm(EditAlarmDlg* dlg, const KAEvent& event)
 {
@@ -1542,7 +1541,7 @@ void MainWindow::editAlarm(EditAlarmDlg* dlg, const KAEvent& event)
 */
 void MainWindow::editAlarmOk()
 {
-    EditAlarmDlg* dlg = qobject_cast<EditAlarmDlg*>(sender());
+    auto* dlg = qobject_cast<EditAlarmDlg*>(sender());
     if (!dlg)
         return;
     QMap<EditAlarmDlg*, KAEvent>::Iterator it = mEditAlarmMap.find(dlg);
