@@ -1,21 +1,9 @@
 /*
  *  reminder.cpp  -  reminder setting widget
  *  Program:  kalarm
- *  Copyright © 2003-2020 David Jarvie <djarvie@kde.org>
+ *  SPDX-FileCopyrightText: 2003-2020 David Jarvie <djarvie@kde.org>
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License along
- *  with this program; if not, write to the Free Software Foundation, Inc.,
- *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ *  SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "reminder.h"
@@ -50,7 +38,7 @@ Reminder::Reminder(const QString& reminderWhatsThis, const QString& valueWhatsTh
     : QFrame(parent)
     , mOnceOnlyEnabled(showOnceOnly)
 {
-    QVBoxLayout* topLayout = new QVBoxLayout(this);
+    auto* topLayout = new QVBoxLayout(this);
     topLayout->setContentsMargins(0, 0, 0, 0);
 
     mTime = new TimeSelector(i18nc("@option:check", "Reminder:"), reminderWhatsThis,
@@ -68,7 +56,7 @@ Reminder::Reminder(const QString& reminderWhatsThis, const QString& valueWhatsTh
 
     if (showOnceOnly)
     {
-        QHBoxLayout* layout = new QHBoxLayout();
+        auto* layout = new QHBoxLayout();
         layout->setContentsMargins(0, 0, 0, 0);
         layout->setContentsMargins(CheckBox::textIndent(mTime), 0, 0, 0);
         topLayout->addLayout(layout);
