@@ -1,21 +1,9 @@
 /*
  *  akonadidatamodel.cpp  -  KAlarm calendar file access using Akonadi
  *  Program:  kalarm
- *  Copyright © 2007-2020 David Jarvie <djarvie@kde.org>
+ *  SPDX-FileCopyrightText: 2007-2020 David Jarvie <djarvie@kde.org>
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License along
- *  with this program; if not, write to the Free Software Foundation, Inc.,
- *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ *  SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "akonadidatamodel.h"
@@ -709,7 +697,7 @@ void AkonadiDataModel::slotRowsInserted(const QModelIndex& parent, int start, in
 */
 void AkonadiDataModel::collectionFetchResult(KJob* j)
 {
-    CollectionFetchJob* job = qobject_cast<CollectionFetchJob*>(j);
+    auto* job = qobject_cast<CollectionFetchJob*>(j);
     if (j->error())
         qCWarning(KALARM_LOG) << "AkonadiDataModel::collectionFetchResult: CollectionFetchJob" << job->fetchScope().resource()<< "error: " << j->errorString();
     else
@@ -941,7 +929,7 @@ QModelIndex AkonadiDataModel::resourceIndex(const Resource& resource) const
     const Collection& collection = AkonadiResource::collection(resource);
     const QModelIndex ix = modelIndexForCollection(this, collection);
     if (!ix.isValid())
-        return QModelIndex();
+        return {};
     return ix;
 }
 
@@ -952,7 +940,7 @@ QModelIndex AkonadiDataModel::resourceIndex(Akonadi::Collection::Id id) const
 {
     const QModelIndex ix = modelIndexForCollection(this, Collection(id));
     if (!ix.isValid())
-        return QModelIndex();
+        return {};
     return ix;
 }
 
@@ -988,13 +976,13 @@ Collection* AkonadiDataModel::collection(const Resource& resource) const
 */
 QModelIndex AkonadiDataModel::itemIndex(const Akonadi::Item& item) const
 {
-    const QModelIndexList ixs = modelIndexesForItem(this, item);
+    const QModelIndexList ixs = modelIndexesForItem(this, item);      //clazy:exclude=inefficient-qlist
     for (const QModelIndex& ix : ixs)
     {
         if (ix.isValid())
             return ix;
     }
-    return QModelIndex();
+    return {};
 }
 
 /******************************************************************************
