@@ -1,28 +1,14 @@
 /*
  *  resource.cpp  -  generic class containing an alarm calendar resource
  *  Program:  kalarm
- *  Copyright © 2019-2020 David Jarvie <djarvie@kde.org>
+ *  SPDX-FileCopyrightText: 2019-2020 David Jarvie <djarvie@kde.org>
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License along
- *  with this program; if not, write to the Free Software Foundation, Inc.,
- *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ *  SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "resources.h"
 
-#include "resource.h"
 #include "resourcedatamodelbase.h"
-#include "resourcemodel.h"
 #include "resourceselectdialog.h"
 
 #include "preferences.h"
@@ -193,8 +179,8 @@ void Resources::setStandard(Resource& resource, CalEvent::Type type, bool standa
         return;
 
     Resources* manager = instance();
-    auto it = manager->mResources.find(resource.id());
-    if (it == manager->mResources.end())
+    auto it = manager->mResources.constFind(resource.id());
+    if (it == manager->mResources.constEnd())
         return;
     resource = it.value();   // just in case it's a different object!
     if (standard == resource.configIsStandard(type))
@@ -223,8 +209,8 @@ void Resources::setStandard(Resource& resource, CalEvent::Types types)
     types &= resource.enabledTypes();
 
     Resources* manager = instance();
-    auto it = manager->mResources.find(resource.id());
-    if (it == manager->mResources.end())
+    auto it = manager->mResources.constFind(resource.id());
+    if (it == manager->mResources.constEnd())
         return;
     resource = it.value();   // just in case it's a different object!
     if (types != resource.configStandardTypes()
