@@ -1,21 +1,9 @@
 /*
  *  resourcescalendar.cpp  -  KAlarm calendar resources access
  *  Program:  kalarm
- *  Copyright © 2001-2020 David Jarvie <djarvie@kde.org>
+ *  SPDX-FileCopyrightText: 2001-2020 David Jarvie <djarvie@kde.org>
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License along
- *  with this program; if not, write to the Free Software Foundation, Inc.,
- *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ *  SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "resourcescalendar.h"
@@ -32,6 +20,7 @@ using namespace KAlarmCal;
 ResourcesCalendar*             ResourcesCalendar::mInstance {nullptr};
 ResourcesCalendar::ResourceMap ResourcesCalendar::mResourceMap;
 ResourcesCalendar::EarliestMap ResourcesCalendar::mEarliestAlarm;
+ResourcesCalendar::EarliestMap ResourcesCalendar::mEarliestNonDispAlarm;
 QSet<QString>                  ResourcesCalendar::mPendingAlarms;
 bool                           ResourcesCalendar::mIgnoreAtLogin {false};
 bool                           ResourcesCalendar::mHaveDisabledAlarms {false};
@@ -84,7 +73,7 @@ ResourcesCalendar::~ResourcesCalendar()
 {
     // Resource map should be empty, but just in case...
     while (!mResourceMap.isEmpty())
-        removeKAEvents(mResourceMap.begin().key(), true, CalEvent::ACTIVE | CalEvent::ARCHIVED | CalEvent::TEMPLATE | CalEvent::DISPLAYING);
+        removeKAEvents(mResourceMap.constBegin().key(), true, CalEvent::ACTIVE | CalEvent::ARCHIVED | CalEvent::TEMPLATE | CalEvent::DISPLAYING);
 }
 
 /******************************************************************************
@@ -123,6 +112,7 @@ void ResourcesCalendar::removeKAEvents(ResourceId key, bool closing, CalEvent::T
     if (removed)
     {
         mEarliestAlarm.remove(key);
+        mEarliestNonDispAlarm.remove(key);
         // Emit signal only if we're not in the process of closing the calendar
         if (!closing)
         {
@@ -205,17 +195,38 @@ void ResourcesCalendar::slotEventUpdated(Resource& resource, const KAEvent& even
     &&  event.category() == CalEvent::ACTIVE)
     {
         // Update the earliest alarm to trigger
-        const QString earliestId = mEarliestAlarm.value(key);
-        if (earliestId == event.id())
+        const QString earliestId        = mEarliestAlarm.value(key);
+        const QString earliestNonDispId = mEarliestNonDispAlarm.value(key);
+        if (earliestId == event.id()  ||  earliestNonDispId == event.id())
             findEarliestAlarm(resource);
         else
         {
             const KADateTime dt = event.nextTrigger(KAEvent::ALL_TRIGGER).effectiveKDateTime();
-            if (dt.isValid()
-            &&  (earliestId.isEmpty()  ||  dt < resource.event(earliestId).nextTrigger(KAEvent::ALL_TRIGGER)))
+            if (dt.isValid())
             {
-                mEarliestAlarm[key] = event.id();
-                Q_EMIT earliestAlarmChanged();
+                bool changed = false;
+                DateTime next;
+                if (!earliestId.isEmpty())
+                    next = resource.event(earliestId).nextTrigger(KAEvent::ALL_TRIGGER);
+                if (earliestId.isEmpty()  ||  dt < next)
+                {
+                    mEarliestAlarm[key] = event.id();
+                    changed = true;
+                }
+                if (!(event.actionTypes() & KAEvent::ACT_DISPLAY))
+                {
+                    // It is not a display event.
+                    DateTime nextNonDisp;
+                    if (!earliestNonDispId.isEmpty())
+                        nextNonDisp = (earliestId == earliestNonDispId) ? next : resource.event(earliestNonDispId).nextTrigger(KAEvent::ALL_TRIGGER);
+                    if (earliestNonDispId.isEmpty()  ||  dt < nextNonDisp)
+                    {
+                        mEarliestNonDispAlarm[key] = event.id();
+                        changed = true;
+                    }
+                }
+                if (changed)
+                    Q_EMIT earliestAlarmChanged();
             }
         }
     }
@@ -238,7 +249,7 @@ void ResourcesCalendar::slotEventsToBeRemoved(Resource& resource, const QList<KA
     const ResourceId key = resource.id();
     for (const KAEvent& event : events)
     {
-        if (mResourceMap[key].contains(event.id()))
+        if (mResourceMap.value(key).contains(event.id()))
             deleteEventInternal(event, resource, false);
     }
 }
@@ -447,7 +458,8 @@ CalEvent::Type ResourcesCalendar::deleteEventInternal(const QString& eventID, co
 {
     const ResourceId key = resource.id();
     mResourceMap[key].remove(eventID);
-    if (mEarliestAlarm.value(key) == eventID)
+    if (mEarliestAlarm.value(key)        == eventID
+    ||  mEarliestNonDispAlarm.value(key) == eventID)
         mInstance->findEarliestAlarm(resource);
 
     CalEvent::Type status = CalEvent::EMPTY;
@@ -502,7 +514,7 @@ KAEvent ResourcesCalendar::templateEvent(const QString& templateName)
     const QVector<KAEvent> eventlist = events(CalEvent::TEMPLATE);
     for (const KAEvent& event : eventlist)
     {
-        if (event.templateName() == templateName)
+        if (event.name() == templateName)
             return event;
     }
     return KAEvent();
@@ -621,7 +633,8 @@ void ResourcesCalendar::checkForDisabledAlarms()
 }
 
 /******************************************************************************
-* Find and note the active alarm with the earliest trigger time for a calendar.
+* Find and note the active alarm with the earliest trigger time for a calendar,
+* and the non-display active alarm with the earliest trigger time.
 */
 void ResourcesCalendar::findEarliestAlarm(const Resource& resource)
 {
@@ -630,28 +643,46 @@ void ResourcesCalendar::findEarliestAlarm(const Resource& resource)
         return;
     if (!(resource.alarmTypes() & CalEvent::ACTIVE))
         return;
+
+    // Invalidate any existing earliest alarms for the resource
     EarliestMap::Iterator eit = mEarliestAlarm.find(key);
     if (eit != mEarliestAlarm.end())
         eit.value() = QString();
+    eit = mEarliestNonDispAlarm.find(key);
+    if (eit != mEarliestNonDispAlarm.end())
+        eit.value() = QString();
+
     ResourceMap::ConstIterator rit = mResourceMap.constFind(key);
     if (rit == mResourceMap.constEnd())
         return;
     const QVector<KAEvent> events = eventsForResource(resource, rit.value());
-    KAEvent earliest;
-    KADateTime earliestTime;
+    KAEvent earliest, earliestNonDisp;
+    KADateTime earliestTime, earliestNonDispTime;
     for (const KAEvent& event : events)
     {
         if (event.category() != CalEvent::ACTIVE
         ||  mPendingAlarms.contains(event.id()))
             continue;
         const KADateTime dt = event.nextTrigger(KAEvent::ALL_TRIGGER).effectiveKDateTime();
-        if (dt.isValid()  &&  (!earliest.isValid() || dt < earliestTime))
+        if (dt.isValid())
         {
-            earliestTime = dt;
-            earliest = event;
+            if (!earliest.isValid() || dt < earliestTime)
+            {
+                earliestTime = dt;
+                earliest = event;
+            }
+            if (!(event.actionTypes() & KAEvent::ACT_DISPLAY))
+            {
+                if (!earliestNonDisp.isValid() || dt < earliestNonDispTime)
+                {
+                    earliestNonDispTime = dt;
+                    earliestNonDisp = event;
+                }
+            }
         }
     }
-    mEarliestAlarm[key] = earliest.id();
+    mEarliestAlarm[key]        = earliest.id();
+    mEarliestNonDispAlarm[key] = earliestNonDisp.id();
     Q_EMIT earliestAlarmChanged();
 }
 
@@ -659,11 +690,12 @@ void ResourcesCalendar::findEarliestAlarm(const Resource& resource)
 * Return the active alarm with the earliest trigger time.
 * Reply = invalid if none.
 */
-KAEvent ResourcesCalendar::earliestAlarm()
+KAEvent ResourcesCalendar::earliestAlarm(KADateTime& nextTriggerTime, bool excludeDisplayAlarms)
 {
     KAEvent earliest;
     KADateTime earliestTime;
-    for (EarliestMap::ConstIterator eit = mEarliestAlarm.constBegin();  eit != mEarliestAlarm.constEnd();  ++eit)
+    const EarliestMap& earliestAlarms(excludeDisplayAlarms ? mEarliestNonDispAlarm : mEarliestAlarm);
+    for (EarliestMap::ConstIterator eit = earliestAlarms.constBegin();  eit != earliestAlarms.constEnd();  ++eit)
     {
         const QString id = eit.value();
         if (id.isEmpty())
@@ -675,8 +707,9 @@ KAEvent ResourcesCalendar::earliestAlarm()
             // Something went wrong: mEarliestAlarm wasn't updated when it should have been!!
             qCCritical(KALARM_LOG) << "ResourcesCalendar::earliestAlarm: resource" << eit.key() << "does not contain" << id;
             mInstance->findEarliestAlarm(res);
-            return earliestAlarm();
+            return earliestAlarm(nextTriggerTime, excludeDisplayAlarms);
         }
+//TODO: use next trigger calculated in findEarliestAlarm() (allowing for it being out of date)?
         const KADateTime dt = event.nextTrigger(KAEvent::ALL_TRIGGER).effectiveKDateTime();
         if (dt.isValid()  &&  (!earliest.isValid() || dt < earliestTime))
         {
@@ -684,6 +717,7 @@ KAEvent ResourcesCalendar::earliestAlarm()
             earliest = event;
         }
     }
+    nextTriggerTime = earliestTime;
     return earliest;
 }
 
@@ -718,6 +752,7 @@ void ResourcesCalendar::setAlarmPending(const KAEvent& event, bool pending)
 QVector<KAEvent> ResourcesCalendar::eventsForResource(const Resource& resource, const QSet<QString>& eventIds)
 {
     QVector<KAEvent> events;
+    events.reserve(eventIds.count());
     for (const QString& eventId : eventIds)
         events += resource.event(eventId);
     return events;
