@@ -1,21 +1,9 @@
 /*
  *  resourcescalendar.h  -  KAlarm calendar resources access
  *  Program:  kalarm
- *  Copyright © 2001-2020 David Jarvie <djarvie@kde.org>
+ *  SPDX-FileCopyrightText: 2001-2020 David Jarvie <djarvie@kde.org>
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License along
- *  with this program; if not, write to the Free Software Foundation, Inc.,
- *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ *  SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #ifndef RESOURCESCALENDAR_H
@@ -48,7 +36,14 @@ public:
     ~ResourcesCalendar() override;
     static void             initialise(const QByteArray& appName, const QByteArray& appVersion);
     static void             terminate();
-    static KAEvent          earliestAlarm();
+
+    /** Return the active alarm with the earliest trigger time.
+     *  @param nextTriggerTime       The next trigger time of the earliest alarm.
+     *  @param excludeDisplayAlarms  Ignore display alarms.
+     *  @return  The earliest alarm.
+     */
+    static KAEvent          earliestAlarm(KADateTime& nextTriggerTime, bool excludeDisplayAlarms = false);
+
     static void             setAlarmPending(const KAEvent&, bool pending = true);
     static bool             haveDisabledAlarms()       { return mHaveDisabledAlarms; }
     static void             disabledChanged(const KAEvent&);
@@ -96,7 +91,8 @@ private:
     typedef QHash<ResourceId, QString> EarliestMap;  // event ID of earliest alarm, for each resource
 
     static ResourceMap    mResourceMap;
-    static EarliestMap    mEarliestAlarm;      // alarm with earliest trigger time, by resource
+    static EarliestMap    mEarliestAlarm;        // alarm with earliest trigger time, by resource
+    static EarliestMap    mEarliestNonDispAlarm; // non-display alarm with earliest trigger time, by resource
     static QSet<QString>  mPendingAlarms;      // IDs of alarms which are currently being processed after triggering
     static bool           mIgnoreAtLogin;      // ignore new/updated repeat-at-login alarms
     static bool           mHaveDisabledAlarms; // there is at least one individually disabled alarm
