@@ -1,21 +1,9 @@
 /*
  *  templatepickdlg.cpp  -  dialog to choose an alarm template
  *  Program:  kalarm
- *  Copyright © 2004-2020 David Jarvie <djarvie@kde.org>
+ *  SPDX-FileCopyrightText: 2004-2020 David Jarvie <djarvie@kde.org>
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License along
- *  with this program; if not, write to the Free Software Foundation, Inc.,
- *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ *  SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "templatepickdlg.h"
@@ -42,7 +30,7 @@ TemplatePickDlg::TemplatePickDlg(KAEvent::Actions type, QWidget* parent)
     : QDialog(parent)
 {
     QWidget* topWidget = new QWidget(this);
-    QVBoxLayout* mainLayout = new QVBoxLayout;
+    auto* mainLayout = new QVBoxLayout;
     setLayout(mainLayout);
     mainLayout->addWidget(topWidget);
     setWindowTitle(i18nc("@title:window", "Choose Alarm Template"));
@@ -53,7 +41,7 @@ TemplatePickDlg::TemplatePickDlg(KAEvent::Actions type, QWidget* parent)
     mOkButton->setShortcut(Qt::CTRL | Qt::Key_Return);
     connect(buttonBox, &QDialogButtonBox::accepted, this, &TemplatePickDlg::accept);
     connect(buttonBox, &QDialogButtonBox::rejected, this, &TemplatePickDlg::reject);
-    QVBoxLayout* topLayout = new QVBoxLayout(topWidget);
+    auto* topLayout = new QVBoxLayout(topWidget);
     topLayout->setContentsMargins(0, 0, 0, 0);
 
     // Display the list of templates, but exclude command alarms if in kiosk mode.
@@ -111,7 +99,7 @@ void TemplatePickDlg::slotSelectionChanged()
 void TemplatePickDlg::slotDoubleClick(const QModelIndex& ix)
 {
     if ((mListFilterModel->flags(ix) & (Qt::ItemIsEnabled | Qt::ItemIsSelectable)) == (Qt::ItemIsEnabled | Qt::ItemIsSelectable))
-        Q_EMIT accept();
+        accept();
 }
 
 /******************************************************************************
