@@ -1,21 +1,9 @@
 /*
  *  undo.cpp  -  undo/redo facility
  *  Program:  kalarm
- *  Copyright © 2005-2020 David Jarvie <djarvie@kde.org>
+ *  SPDX-FileCopyrightText: 2005-2020 David Jarvie <djarvie@kde.org>
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License along
- *  with this program; if not, write to the Free Software Foundation, Inc.,
- *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ *  SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "undo.h"
@@ -27,7 +15,6 @@
 #include "kalarm_debug.h"
 
 #include <KAlarmCal/AlarmText>
-#include <KAlarmCal/KAEvent>
 
 #include <KLocalizedString>
 
@@ -506,9 +493,9 @@ QString Undo::description(Undo::Type type, int id)
 * listed, to force dependent undos to be executed in their correct order.
 * If 'ids' is non-null, also returns a list of their corresponding IDs.
 */
-QList<int> Undo::ids(Undo::Type type)
+QVector<int> Undo::ids(Undo::Type type)
 {
-    QList<int> ids;
+    QVector<int> ids;
     QStringList ignoreIDs;
 //int n=0;
     const List* const list = (type == UNDO) ? &mUndoList : (type == REDO) ? &mRedoList : nullptr;
@@ -656,7 +643,7 @@ UndoItem::~UndoItem()
 */
 QString UndoItem::description(const KAEvent& event) const
 {
-    return (mCalendar == CalEvent::TEMPLATE) ? event.templateName() : AlarmText::summary(event);
+    return (mCalendar == CalEvent::TEMPLATE) ? event.name() : AlarmText::summary(event);
 }
 
 /******************************************************************************
@@ -742,7 +729,7 @@ UndoMulti<T>::UndoMulti(Undo::Type type, const Undo::EventList& events, const QS
 template <class T>
 UndoItem* UndoMulti<T>::restore()
 {
-    Undo::List* newUndos = new Undo::List;
+    auto* newUndos = new Undo::List;
     for (int i = 0, end = mUndos->count();  i < end;  ++i)
     {
         UndoItem* undo = (*mUndos)[i]->restore();
